pub struct BitWriter<'a> { /* private fields */ }Available on crate feature
bit-packing only.Expand description
Bit-level output over caller-owned memory, least-significant bit first.
Implementations
Sourceimpl<'a> BitWriter<'a>
impl<'a> BitWriter<'a>
Sourcepub fn new(output: &'a mut [u8]) -> Self
pub fn new(output: &'a mut [u8]) -> Self
Creates a writer and clears the output so padding is canonical zero.
Sourcepub fn write(&mut self, value: u128, width: usize) -> Result<()>
pub fn write(&mut self, value: u128, width: usize) -> Result<()>
Writes the low width bits of value.
Sourcepub const fn bits_written(&self) -> usize
pub const fn bits_written(&self) -> usize
Number of meaningful bits written.
Sourcepub const fn bytes_written(&self) -> usize
pub const fn bytes_written(&self) -> usize
Number of bytes containing meaningful bits or canonical padding.