pub struct EncryptedConfig { /* private fields */ }Available on crate feature
encryption only.Expand description
Authenticated encryption applied after serialization and optional compression.
Implementations
Sourceimpl EncryptedConfig
impl EncryptedConfig
Sourcepub const fn with_plaintext_limit(self, limit: u64) -> Self
pub const fn with_plaintext_limit(self, limit: u64) -> Self
Overrides the maximum authenticated plaintext frame size.
Sourcepub fn serialize<T: NsonSerialize + ?Sized>(&self, value: &T) -> Result<Vec<u8>>
pub fn serialize<T: NsonSerialize + ?Sized>(&self, value: &T) -> Result<Vec<u8>>
Serializes and encrypts a value with a fresh random 192-bit nonce.
Sourcepub fn deserialize<T: for<'de> NsonDeserialize<'de>>(
&self,
input: &[u8],
) -> Result<T>
pub fn deserialize<T: for<'de> NsonDeserialize<'de>>( &self, input: &[u8], ) -> Result<T>
Decrypts, authenticates, and deserializes a complete frame.
Sourcepub fn deserialize_from<R: Read, T: for<'de> NsonDeserialize<'de>>(
&self,
reader: R,
) -> Result<T>
pub fn deserialize_from<R: Read, T: for<'de> NsonDeserialize<'de>>( &self, reader: R, ) -> Result<T>
Reads exactly one encrypted frame and leaves subsequent frames unread.