Module evolution

Module evolution 

Available on crate feature schema-evolution only.
Stable-field-ID schema evolution.

Structs

EvolutionConfig
Configuration for stable-field-ID schema evolution frames.
FieldDecoder
Stable-ID field access used by SchemaDecode implementations.
FieldEncoder
Builder used by SchemaEncode implementations.
UnknownField
Borrowed unknown field exposed for forwarding or application migrations.

Traits

SchemaDecode
Decoding contract for a type that accepts compatible schema revisions.
SchemaEncode
Encoding contract for a type with stable field identifiers.