Module schema

Module schema 

Available on crate feature fingerprint only.
Compile-time schema identity and fingerprinted frame support.

Structs

FingerprintedConfig
A configuration that prefixes values with a versioned schema fingerprint.

Constants

FNV_OFFSET
Initial state for the stable FNV-1a schema hash.

Traits

Fingerprint
Stable structural identity for a serializable Rust type.

Functions

hash_bytes
Extends a schema hash with an exact byte sequence.
hash_u64
Extends a schema hash with one little-endian u64 domain value.