Available on crate feature
schema-evolution only.Expand description
Stable-field-ID schema evolution.
Structs
- Evolution
Config - Configuration for stable-field-ID schema evolution frames.
- Field
Decoder - Stable-ID field access used by
SchemaDecodeimplementations. - Field
Encoder - Builder used by
SchemaEncodeimplementations. - Unknown
Field - Borrowed unknown field exposed for forwarding or application migrations.
Traits
- Schema
Decode - Decoding contract for a type that accepts compatible schema revisions.
- Schema
Encode - Encoding contract for a type with stable field identifiers.