pub fn deserialize<'de, T: Deserialize<'de>>(input: &'de [u8]) -> Result<T>Expand description
Deserializes from a slice with the bounded compact Core profile.
The returned value may borrow strings and byte slices from input.
pub fn deserialize<'de, T: Deserialize<'de>>(input: &'de [u8]) -> Result<T>Deserializes from a slice with the bounded compact Core profile.
The returned value may borrow strings and byte slices from input.