pub struct ParallelConfig { /* private fields */ }Available on crate feature
parallel only.Expand description
Ordered parallel batch codec over a base binary configuration.
Elements are encoded independently on scoped worker threads. The frame stores an ordered length table, so scheduling cannot affect output bytes.
Implementations
Sourceimpl ParallelConfig
impl ParallelConfig
Sourcepub const fn base_config(self) -> Config
pub const fn base_config(self) -> Config
Returns the underlying wire and resource configuration.
Sourcepub const fn with_worker_count(self, workers: NonZeroUsize) -> Self
pub const fn with_worker_count(self, workers: NonZeroUsize) -> Self
Uses at most workers scoped threads.
Sourcepub const fn worker_count(self) -> NonZeroUsize
pub const fn worker_count(self) -> NonZeroUsize
Returns the configured worker ceiling.
Sourcepub fn serialize_batch<T: Serialize + Sync>(
self,
values: &[T],
) -> Result<Vec<u8>>
pub fn serialize_batch<T: Serialize + Sync>( self, values: &[T], ) -> Result<Vec<u8>>
Encodes an ordered collection as a deterministic parallel batch frame.
Sourcepub fn deserialize_batch<T: DeserializeOwned + Send>(
self,
input: &[u8],
) -> Result<Vec<T>>
pub fn deserialize_batch<T: DeserializeOwned + Send>( self, input: &[u8], ) -> Result<Vec<T>>
Validates and decodes an ordered parallel batch frame.