Available on crate feature
fingerprint only.Expand description
Compile-time schema identity and fingerprinted frame support.
Structs
- Fingerprinted
Config - A configuration that prefixes values with a versioned schema fingerprint.
Constants
- FNV_
OFFSET - Initial state for the stable FNV-1a schema hash.
Traits
- Fingerprint
- Stable structural identity for a serializable Rust type.
Functions
- hash_
bytes - Extends a schema hash with an exact byte sequence.
- hash_
u64 - Extends a schema hash with one little-endian
u64domain value.